@@ -22,7 +22,7 @@ typedef int (* error_handler_t) (const char * source_file,
                                  int source_line_number,
                                  const char * message, ...)
 #ifdef __GNUC__
-    __attribute__((format (printf, 3, 4)))
+    __attribute__ ((format (printf, 3, 4)))
 #endif /* __GNUC__ */
 ;
 #endif /* ndef ERROR_HANDLER_H */
@@ -42,7 +42,7 @@ text_fuzzy_default_error_handler (const char * source_file,
     fprintf (stderr, "%s:%d: ", source_file, source_line_number);
     va_start (args, message);
     vfprintf (stderr, message, args);
-    exit (EXIT_FAILURE);
+    return 0;
 }
 
 /* This global variable is the error handler for this namespace. */
@@ -95,7 +95,6 @@ static void fail_msg (int condition, int status, char * msg, ...)
 {
     if (condition) {
 	fprintf (stderr, "%d:%s", status, msg);
-	exit (1);
     }
 }
 
@@ -417,7 +416,7 @@ FUNC (generate_ualphabet) (text_fuzzy_t * tf)
     /* Create a zeroed alphabet. */
 
     u->alphabet = calloc (u->size, sizeof (char));
-    FAIL_MSG (! u->alphabet, memory_error, "Could not allocate %d memory slots",
+    FAIL_MSG (! u->alphabet, memory_failure, "Could not allocate %d memory slots",
 	      u->size);
 
     tf->n_mallocs++;
@@ -699,7 +698,7 @@ FUNC (compare_single) (text_fuzzy_t * tf)
 	if (tf->wantarray) {
 	    candidate_t * c;
 	    c = malloc (sizeof (candidate_t));
-	    FAIL (! c, memory_error);
+	    FAIL (! c, memory_failure);
 	    tf->n_mallocs+=1;
 	    c->distance = d;
 	    c->offset = tf->offset;
@@ -737,7 +736,7 @@ FUNC (get_candidates) (text_fuzzy_t * text_fuzzy,
     }
 
     candidates = malloc (sizeof (int) * n_candidates);
-    FAIL (! candidates, memory_error);
+    FAIL (! candidates, memory_failure);
     text_fuzzy->n_mallocs+=1;
 
     last = text_fuzzy->first.next;
@@ -984,7 +983,7 @@ FUNC (scan_file) (text_fuzzy_t * text_fuzzy, char * file_name,
 	    else {
 		nearest = realloc (nearest, ff.b.length + 1);
 	    }
-	    FAIL (! nearest, memory_error);
+	    FAIL (! nearest, memory_failure);
 	    strncpy (nearest, ff.b.text, ff.b.length);
 	    nearest[ff.b.length] = '\0';
         }
