@@ -7,7 +7,7 @@ typedef int (* error_handler_t) (const char * source_file,
                                  int source_line_number,
                                  const char * message, ...)
 #ifdef __GNUC__
-    __attribute__((format (printf, 3, 4)))
+    __attribute__ ((format (printf, 3, 4)))
 #endif /* __GNUC__ */
 ;
 #endif /* ndef ERROR_HANDLER_H */
@@ -66,7 +66,7 @@ static void default_error_handler (const char * file, int line,
 
 typedef enum {
     text_fuzzy_status_ok,
-    text_fuzzy_status_memory_error,
+    text_fuzzy_status_memory_failure,
     text_fuzzy_status_open_error,
     text_fuzzy_status_close_error,
     text_fuzzy_status_read_error,
@@ -80,7 +80,7 @@ typedef enum {
 text_fuzzy_status_t;
 #ifndef __GNUC__
 static int ok = text_fuzzy_status_ok;
-static int memory_error = text_fuzzy_status_memory_error;
+static int memory_failure = text_fuzzy_status_memory_failure;
 static int open_error = text_fuzzy_status_open_error;
 static int close_error = text_fuzzy_status_close_error;
 static int read_error = text_fuzzy_status_read_error;
@@ -248,43 +248,43 @@ text_fuzzy_t;
 
 #define TEXT_FUZZY_INVALID_UNICODE_LENGTH -1
 #line 193 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_generate_ualphabet (text_fuzzy_t * tf);
+text_fuzzy_status_t text_fuzzy_generate_ualphabet (text_fuzzy_t * tf) __attribute__ ((warn_unused_result));
 #line 379 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_compare_single (text_fuzzy_t * tf);
+text_fuzzy_status_t text_fuzzy_compare_single (text_fuzzy_t * tf) __attribute__ ((warn_unused_result));
 #line 556 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_get_candidates (text_fuzzy_t * text_fuzzy, int * n_candidates_ptr, int ** candidates_ptr);
+text_fuzzy_status_t text_fuzzy_get_candidates (text_fuzzy_t * text_fuzzy, int * n_candidates_ptr, int ** candidates_ptr) __attribute__ ((warn_unused_result));
 #line 613 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_free_candidates (text_fuzzy_t * text_fuzzy, int * candidates);
+text_fuzzy_status_t text_fuzzy_free_candidates (text_fuzzy_t * text_fuzzy, int * candidates) __attribute__ ((warn_unused_result));
 #line 630 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_generate_alphabet (text_fuzzy_t * text_fuzzy);
+text_fuzzy_status_t text_fuzzy_generate_alphabet (text_fuzzy_t * text_fuzzy) __attribute__ ((warn_unused_result));
 #line 668 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_begin_scanning (text_fuzzy_t * text_fuzzy);
+text_fuzzy_status_t text_fuzzy_begin_scanning (text_fuzzy_t * text_fuzzy) __attribute__ ((warn_unused_result));
 #line 699 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_end_scanning (text_fuzzy_t * text_fuzzy);
+text_fuzzy_status_t text_fuzzy_end_scanning (text_fuzzy_t * text_fuzzy) __attribute__ ((warn_unused_result));
 #line 793 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_scan_file (text_fuzzy_t * text_fuzzy, char * file_name, char ** nearest_ptr);
+text_fuzzy_status_t text_fuzzy_scan_file (text_fuzzy_t * text_fuzzy, char * file_name, char ** nearest_ptr) __attribute__ ((warn_unused_result));
 #line 839 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_alphabet_rejections (text_fuzzy_t * text_fuzzy, int * r);
+text_fuzzy_status_t text_fuzzy_alphabet_rejections (text_fuzzy_t * text_fuzzy, int * r) __attribute__ ((warn_unused_result));
 #line 852 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_free_memory (text_fuzzy_t * text_fuzzy);
+text_fuzzy_status_t text_fuzzy_free_memory (text_fuzzy_t * text_fuzzy) __attribute__ ((warn_unused_result));
 #line 858 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_set_max_distance (text_fuzzy_t * text_fuzzy, int max_distance);
+text_fuzzy_status_t text_fuzzy_set_max_distance (text_fuzzy_t * text_fuzzy, int max_distance) __attribute__ ((warn_unused_result));
 #line 864 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_get_max_distance (text_fuzzy_t * text_fuzzy, int * max_distance);
+text_fuzzy_status_t text_fuzzy_get_max_distance (text_fuzzy_t * text_fuzzy, int * max_distance) __attribute__ ((warn_unused_result));
 #line 870 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_set_transpositions (text_fuzzy_t * text_fuzzy, int transpositions);
+text_fuzzy_status_t text_fuzzy_set_transpositions (text_fuzzy_t * text_fuzzy, int transpositions) __attribute__ ((warn_unused_result));
 #line 876 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_get_transpositions (text_fuzzy_t * text_fuzzy, int * transpositions);
+text_fuzzy_status_t text_fuzzy_get_transpositions (text_fuzzy_t * text_fuzzy, int * transpositions) __attribute__ ((warn_unused_result));
 #line 882 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_last_distance (text_fuzzy_t * text_fuzzy, int * last_distance);
+text_fuzzy_status_t text_fuzzy_last_distance (text_fuzzy_t * text_fuzzy, int * last_distance) __attribute__ ((warn_unused_result));
 #line 892 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_no_alphabet (text_fuzzy_t * text_fuzzy, int yes_no);
+text_fuzzy_status_t text_fuzzy_no_alphabet (text_fuzzy_t * text_fuzzy, int yes_no) __attribute__ ((warn_unused_result));
 #line 898 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_ualphabet_rejections (text_fuzzy_t * text_fuzzy, int * ualphabet_rejections);
+text_fuzzy_status_t text_fuzzy_ualphabet_rejections (text_fuzzy_t * text_fuzzy, int * ualphabet_rejections) __attribute__ ((warn_unused_result));
 #line 904 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_set_no_exact (text_fuzzy_t * text_fuzzy, int yes_no);
+text_fuzzy_status_t text_fuzzy_set_no_exact (text_fuzzy_t * text_fuzzy, int yes_no) __attribute__ ((warn_unused_result));
 #line 910 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_get_length_rejections (text_fuzzy_t * text_fuzzy, int * length_rejections);
+text_fuzzy_status_t text_fuzzy_get_length_rejections (text_fuzzy_t * text_fuzzy, int * length_rejections) __attribute__ ((warn_unused_result));
 #line 921 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
-text_fuzzy_status_t text_fuzzy_get_unicode_length (text_fuzzy_t * text_fuzzy, int * unicode_length);
+text_fuzzy_status_t text_fuzzy_get_unicode_length (text_fuzzy_t * text_fuzzy, int * unicode_length) __attribute__ ((warn_unused_result));
 #endif /* TEXT_FUZZY_H */
